==> kdeedu-3.0.1.tar.bz2: kdeedu-3.0.1/kmessedwords/kmessedwords/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Thu Jul 19 00:06:05 CEST 2001
    copyright            : (C) 2001 by Primoz Anzur (zer0Kode)
    email                : zerokode@yahoo.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>

#include "mainwindow.h"
#include "splashscreen.h"

static const char *description =
	I18N_NOOP("Letter Order Game");
// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE


static KCmdLineOptions options[] =
{
  { 0, 0, 0 }
  // INSERT YOUR COMMANDLINE OPTIONS HERE
};

int main(int argc, char *argv[])
{

  KAboutData aboutData( "kmessedwords", I18N_NOOP("KMessedWords"),
    LOCAL_VERSION, description, KAboutData::License_GPL,
    "(c) 2001, Primoz Anzur (zer0Kode)", 0, "http://edu.kde.org/kmessedwords", "submit@bugs.kde.org");
  aboutData.addAuthor("Primoz Anzur (zer0Kode)","Creator, maintainer, graphic design", "zerokode@yahoo.com");
  aboutData.addAuthor("Waldo Bastian","Created the core KMW engine", "bastian@kde.org");
  aboutData.addAuthor("Chris Howells","Added \"Help\" menu", "howells@kde.org");
  KCmdLineArgs::init( argc, argv, &aboutData );
  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.

//  KApplication a;
//  MainWindow *mainwindow = new MainWindow();
//  a.setMainWidget(mainwindow);
//  mainwindow->show();

  KApplication a;
  SplashScreen *splashscreen = new SplashScreen();
  a.setMainWidget(splashscreen);
  splashscreen->show();

  return a.exec();
}

==> kdeedu-3.1.tar.bz2: kdeedu-3.1/kmessedwords/kmessedwords/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Thu Jul 19 00:06:05 CEST 2001
    copyright            : (C) 2001 by Primoz Anzur (zer0Kode)
    email                : zerokode@yahoo.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>

#include "mainwindow.h"
//#include "splashscreen.h"

static const char *description =
	I18N_NOOP("Letter Order Game");
// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE


static KCmdLineOptions options[] =
{
  { 0, 0, 0 }
  // INSERT YOUR COMMANDLINE OPTIONS HERE
};

int main(int argc, char *argv[])
{

  KAboutData aboutData( "kmessedwords", I18N_NOOP("KMessedWords"),
    LOCAL_VERSION, description, KAboutData::License_GPL,
    "(c) 2001 - 2002, Whitehawk Stormchaser", 0, "http://edu.kde.org/kmessedwords", "submit@bugs.kde.org");
  aboutData.addAuthor("Whitehawk Stormchaser","Creator, maintainer, graphic design", "zerokode@gmx.net");
  aboutData.addCredit("Waldo Bastian","Created the core KMW engine / improved syllables engine", "bastian@kde.org");
  aboutData.addCredit("Chris Howells","Added \"Help\" menu", "howells@kde.org");
  KCmdLineArgs::init( argc, argv, &aboutData );
  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.

  KApplication a;
  MainWindow *mw = new MainWindow();
  a.setMainWidget(mw);
  mw->show();

  return a.exec();
}
